.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

TotalDepth.util.DictTree (Tree-like Dictionary)
================================================

.. automodule:: TotalDepth.util.DictTree
	:member-order: bysource
	:members:
	:special-members:

